<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/14/2003 *
 * ===================                          Last change: 04/28/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-login.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Login area (redirects to the real login module)  *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Loginbereich (leitet an das richtige Lgin-Modul  *
 *                     weiter)                                          *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Add description as navigation point
addMenuDescription('guest', __FILE__);

if ((!isExtensionActive('user')) && (!isAdmin())) {
	loadTemplate('admin_settings_saved', false, generateExtensionInactiveNotInstalledMessage('user'));
	return;
} // END - if

// Initialize variables
$errorCode = '0';
$userid = false;
$hash = '';
$url = '';
$add = '';

// Already logged in?
if ((isMemberIdSet()) && (isSessionVariableSet('u_hash'))) {
	// Maybe, then continue with it
	$userid = getMemberId();
} elseif ((isPostRequestParameterSet('id')) && (isPostRequestParameterSet('password')) && (isFormSent())) {
	// Set userid and crypt password when login data was submitted
	if (isExtensionActive('nickname')) {
		// Nickname entered
		$userid = SQL_ESCAPE(postRequestParameter('id'));
	} else {
		// Direct userid entered
		$userid  = bigintval(postRequestParameter('id'));
	}
} elseif (isPostRequestParameterSet('new_pass')) {
	// New password requested
	$userid = '0';
	if (isPostRequestParameterSet('id')) {
		// Do we have nickname or userid?
		if ((isExtensionActive('nickname')) && (isNicknameUsed(postRequestParameter('id')))) {
			// Nickname entered
			$userid = SQL_ESCAPE(postRequestParameter('id'));
		} else {
			// Direct userid entered
			$userid  = bigintval(postRequestParameter('id'));
		}
	} // END - if
} else {
	// Not logged in
	$userid = '0'; $hash = '';
}

if (isMember()) {
	// Login immidiately...
	$url = 'modules.php?module=login';
} elseif ((isFormSent()) && ('' . $userid . '' != '' . postRequestParameter('id') . '')) {
	// Invalid input (no nickname extension installed but nickname entered)
	$errorCode = getCode('EXTENSION_PROBLEM');
} elseif (isFormSent()) {
	// Try the login (see inc/libs/user_functions.php)
	$url = doUserLogin(postRequestParameter('id'), postRequestParameter('password'));
} elseif ((isPostRequestParameterSet('new_pass')) && (isset($userid))) {
	// Try the userid/email lookup (see inc/libs/user_functions.php)
	$errorCode = doNewUserPassword(postRequestParameter('email'), $userid);
}

// Login problems?
if (isGetRequestParameterSet('login')) {
	// Use code from URL
	$errorCode = getRequestParameter('login');
} // END  - if

// No problems, no output by detault
$content['message'] = '';

// Login problems?
if (!empty($errorCode)) {
	// Do we have a userid set?
	if (isSessionVariableSet('current_userid')) {
		// Then prefetch data for this account
		fetchUserData(getSession('current_userid'));
	} // END - if

	// @TODO Move this HTML code into a template
	$content['message'] = '<tr>
  <td colspan="4" align="center">
    <span class="notice">' . getMessageFromErrorCode($errorCode) . '</span>
  </td>
</tr>';
} // END - if

// Display login form with resend-password form
if (isExtensionActive('nickname')) {
	loadTemplate('guest_nickname_login', false, $content);
} else {
	loadTemplate('guest_login', false, $content);
}

// Was an URL constructed?
if (!empty($url)) {
	// URL was constructed
	if (ifFatalErrorsDetected()) {
		// Handle fatal errors
		runFilterChain('handle_fatal_errors');
	} else {
		// Load URL
		redirectToUrl($url);
	}
} // END - if

// [EOF]
?>
